
-- worldmap_addDesc(codename, lang, levelname, desc)
worldmap_addDesc("menu", "en", "Game menu", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "cs", "Herní menu", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "fr", "Menu", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "de", "Menü", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "it", "Menù", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "pl", "Menu", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "es", "Menú", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "nl", "Menu", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "bg", "Меню", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "sv", "Meny", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "sl", "Menu igre", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "pt_BR", "Menu", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "ru", "Меню", "Fish Fillets - Next Generation")
worldmap_addDesc("menu", "eo", "Menuo, ", "Fish Fillets - Next Generation")

worldmap_addDesc("start", "en", "How It All Started", "Fish House")
worldmap_addDesc("start", "cs", "Jak to všechno začalo", "Rybí domeček")
worldmap_addDesc("start", "fr", "Comment tout a commencé", "Maison Poisson")
worldmap_addDesc("start", "de", "Wie alles anfing", "Fischhaus")
worldmap_addDesc("start", "it", "Come è iniziato tutto", "La Casa dei Pesci")
worldmap_addDesc("start", "pl", "Jak to się wszystko zaczęło", "Rybi domek")
worldmap_addDesc("start", "es", "Como Empezó Todo", "Casa Pez")
worldmap_addDesc("start", "nl", "Hoe het allemaal begon", "Vissenhuis")
worldmap_addDesc("start", "bg", "Как започна всичко", "Дома на рибките")
worldmap_addDesc("start", "sv", "Hur allt började", "Fiskhuset")
worldmap_addDesc("start", "sl", "Kako se je vse začelo", "Ribja hiša")
worldmap_addDesc("start", "pt_BR", "Como Tudo Começou", "Peixaria")
worldmap_addDesc("start", "ru", "Как всё начиналось", "Рыбий дом")
worldmap_addDesc("start", "eo", "Kiel ĉio komenciĝis", "Fiŝa domo")

worldmap_addDesc("briefcase", "en", "Briefcase Message", "Fish House")
worldmap_addDesc("briefcase", "cs", "Podivná zásilka", "Rybí domeček")
worldmap_addDesc("briefcase", "fr", "La Valise-Message", "Maison Poisson")
worldmap_addDesc("briefcase", "de", "Die Nachricht in der Aktentasche", "Fischhaus")
worldmap_addDesc("briefcase", "it", "Messaggio nella valigetta", "La Casa dei Pesci")
worldmap_addDesc("briefcase", "pl", "Wiadomość z walizki", "Rybi domek")
worldmap_addDesc("briefcase", "es", "Mensaje de un Maletín", "Casa Pez")
worldmap_addDesc("briefcase", "nl", "Het bericht in het koffertje", "Vissenhuis")
worldmap_addDesc("briefcase", "bg", "Събщение в куфарче", "Дома на рибките")
worldmap_addDesc("briefcase", "sv", "Portföljmeddelandet", "Fiskhuset")
worldmap_addDesc("briefcase", "sl", "Sporočilo v kovčku", "Ribja hiša")
worldmap_addDesc("briefcase", "pt_BR", "Mensagem na Maleta", "Peixaria")
worldmap_addDesc("briefcase", "ru", "Сообщение из чемодана", "Рыбий дом")

worldmap_addDesc("cellar", "en", "Rehearsal in Cellar", "Fish House")
worldmap_addDesc("cellar", "cs", "Zkouška ve sklepě", "Rybí domeček")
worldmap_addDesc("cellar", "fr", "Répétition dans la cave", "Maison Poisson")
worldmap_addDesc("cellar", "de", "Die Probe im Keller", "Fischhaus")
worldmap_addDesc("cellar", "it", "Prove in cantina", "La Casa dei Pesci")
worldmap_addDesc("cellar", "pl", "Ćwiczenia w piwnicy", "Rybi domek")
worldmap_addDesc("cellar", "es", "Ensayo en el Sótano", "Casa Pez")
worldmap_addDesc("cellar", "nl", "De oefening in de kelder", "Vissenhuis")
worldmap_addDesc("cellar", "bg", "Упражнение в мазето", "Дома на рибките")
worldmap_addDesc("cellar", "sv", "Repetition i källaren", "Fiskhuset")
worldmap_addDesc("cellar", "sl", "Generalka v kleti", "Ribja hiša")
worldmap_addDesc("cellar", "pt_BR", "Ensaio no Porão", "Peixaria")
worldmap_addDesc("cellar", "ru", "Репетиция в подвале", "Рыбий дом")

worldmap_addDesc("library", "en", "Library Flotsam", "Fish House")
worldmap_addDesc("library", "cs", "Co zbylo z knihovny", "Rybí domeček")
worldmap_addDesc("library", "fr", "La bibliothèque", "Maison Poisson")
worldmap_addDesc("library", "de", "Bibliothek Strandgut", "Fischhaus")
worldmap_addDesc("library", "it", "Relitto di biblioteca", "La Casa dei Pesci")
worldmap_addDesc("library", "pl", "Wrak w bibliotece", "Rybi domek")
worldmap_addDesc("library", "es", "La Biblioteca", "Casa Pez")
worldmap_addDesc("library", "nl", "Strandjutterbiblioteek", "Vissenhuis")
worldmap_addDesc("library", "bg", "Потъналата библиотека", "Дома на рибките")
worldmap_addDesc("library", "sv", "Vrakgods i biblioteket", "Fiskhuset")
worldmap_addDesc("library", "pt_BR", "A Biblioteca", "Peixaria")
worldmap_addDesc("library", "ru", "Утонувшая библиотека", "Рыбий дом")

worldmap_addDesc("stairs", "en", "Plants on the Stairs", "Fish House")
worldmap_addDesc("stairs", "cs", "Zeleň na schodišti", "Rybí domeček")
worldmap_addDesc("stairs", "fr", "Des plantes dans les escaliers", "Maison Poisson")
worldmap_addDesc("stairs", "de", "Pflanzen auf der Treppe", "Fischhaus")
worldmap_addDesc("stairs", "it", "Piante sulle scale", "La Casa dei Pesci")
worldmap_addDesc("stairs", "pl", "Kwiatek na schodach", "Rybi domek")
worldmap_addDesc("stairs", "es", "Plantas en las Escaleras", "Casa Pez")
worldmap_addDesc("stairs", "nl", "Planten op de trap", "Vissenhuis")
worldmap_addDesc("stairs", "bg", "Цветя на стълбите", "Дома на рибките")
worldmap_addDesc("stairs", "sv", "Krukväxten i trappan", "Fiskhuset")
worldmap_addDesc("stairs", "sl", "Zelenje na stopnicah", "Ribja hiša")
worldmap_addDesc("stairs", "pt_BR", "Plantas nas Escadas", "Peixaria")
worldmap_addDesc("stairs", "ru", "Растения на ступеньках", "Рыбий дом")

worldmap_addDesc("broom", "en", "A Mess in the Boiler Room", "Fish House")
worldmap_addDesc("broom", "cs", "Nepořádek v kotelně", "Rybí domeček")
worldmap_addDesc("broom", "fr", "Réunion dans la chaudière", "Maison Poisson")
worldmap_addDesc("broom", "de", "Unordnung im Kesselraum", "Fischhaus")
worldmap_addDesc("broom", "it", "Casino in sala caldaia", "La Casa dei Pesci")
worldmap_addDesc("broom", "pl", "Bałagan w kotłowni", "Rybi domek")
worldmap_addDesc("broom", "es", "Un Desorden en la Caldera", "Casa Pez")
worldmap_addDesc("broom", "nl", "Rommel in het boilerhok", "Vissenhuis")
worldmap_addDesc("broom", "bg", "Бъркотия в котелното", "Дома на рибките")
worldmap_addDesc("broom", "sv", "Oreda i pannrummet", "Fiskhuset")
worldmap_addDesc("broom", "sl", "Zmeda v kotlovnici", "Ribja hiša")
worldmap_addDesc("broom", "pt_BR", "Bagunça na Caldeira", "Peixaria")
worldmap_addDesc("broom", "ru", "Беспорядок в бойлерной", "Рыбий дом")

worldmap_addDesc("reef", "en", "Under the Reef", "Fish House")
worldmap_addDesc("reef", "cs", "Pod útesem", "Rybí domeček")
worldmap_addDesc("reef", "fr", "Sous le récif", "Maison Poisson")
worldmap_addDesc("reef", "de", "Unter dem Riff", "Fischhaus")
worldmap_addDesc("reef", "it", "Sotto la scogliera", "La Casa dei Pesci")
worldmap_addDesc("reef", "pl", "Pod rafą", "Rybi domek")
worldmap_addDesc("reef", "es", "Bajo el Arrecife", "Casa Pez")
worldmap_addDesc("reef", "nl", "Onder het rif", "Vissenhuis")
worldmap_addDesc("reef", "bg", "Под рифа", "Дома на рибките")
worldmap_addDesc("reef", "sv", "Under revet", "Fiskhuset")
worldmap_addDesc("reef", "sl", "Pod grebenom", "Ribja Hiša")
worldmap_addDesc("reef", "pt_BR", "Abaixo do Recife", "Peixaria")
worldmap_addDesc("reef", "ru", "Под рифом", "Рыбий дом")

worldmap_addDesc("wc", "en", "Closed in the Closet", "Fish House")
worldmap_addDesc("wc", "cs", "Zamčeni na WC", "Rybí domeček")
worldmap_addDesc("wc", "fr", "Bloqués dans les toilettes", "Maison Poisson")
worldmap_addDesc("wc", "de", "Eingeschlossen auf Toilette", "Fischhaus")
worldmap_addDesc("wc", "it", "Rinchiusi in bagno", "La Casa dei Pesci")
worldmap_addDesc("wc", "pl", "Zamknięci w klozecie", "Rybi domek")
worldmap_addDesc("wc", "es", "Encerrado en el W.C.", "Casa Pez")
worldmap_addDesc("wc", "nl", "Opgesloten op de wc", "Vissenhuis")
worldmap_addDesc("wc", "bg", "Затворени в клозета", "Дома на рибките")
worldmap_addDesc("wc", "sv", "Inlåst i garderoben", "Fiskhuset")
worldmap_addDesc("wc", "sl", "Zaprti na stranišču", "Ribja hiša")
worldmap_addDesc("wc", "pt_BR", "Trancado no Banheiro", "Peixaria")
worldmap_addDesc("wc", "ru", "Запертые в туалете", "Рыбий дом")

worldmap_addDesc("submarine", "en", "Drowned Submarine", "Ship Wrecks")
worldmap_addDesc("submarine", "cs", "Utonulá ponorka", "Vrakoviště")
worldmap_addDesc("submarine", "fr", "Le sous-marin englouti", "Les épaves")
worldmap_addDesc("submarine", "de", "Versunkenes U-Boot", "Schiffswracks")
worldmap_addDesc("submarine", "it", "Il sottomarino annegato", "Navi fracassate")
worldmap_addDesc("submarine", "pl", "Zatopiona łódź podwodna", "Cmentarzysko statków")
worldmap_addDesc("submarine", "es", "Submarino Ahogado", "Ruinas del Barco")
worldmap_addDesc("submarine", "nl", "De gezonken duikboot", "Scheepswrakken")
worldmap_addDesc("submarine", "bg", "Потъналата подводница", "Корабни останки")
worldmap_addDesc("submarine", "sv", "Den sjunkna ubåten", "Skeppsvrak")
worldmap_addDesc("submarine", "sl", "Potopljena podmornica", "Ladijske razbitine")
worldmap_addDesc("submarine", "pt_BR", "Naufrágio do Submarino", "Destroços do Navio")
worldmap_addDesc("submarine", "ru", "Затонувшая субмарина", "Кораблекрушения")

worldmap_addDesc("party1", "en", "Picnic Boat", "Ship Wrecks")
worldmap_addDesc("party1", "cs", "Výletní loď", "Vrakoviště")
worldmap_addDesc("party1", "fr", "le bateau pique-nique", "Les épaves")
worldmap_addDesc("party1", "de", "Picknickboot", "Schiffswracks")
worldmap_addDesc("party1", "it", "Pic-nic in barca", "Navi fracassate")
worldmap_addDesc("party1", "pl", "Łódź wycieczkowa", "Cmentarzysko statków")
worldmap_addDesc("party1", "es", "Bote Picnic", "Ruinas del Barco")
worldmap_addDesc("party1", "nl", "Picknickboot", "Scheepswrakken")
worldmap_addDesc("party1", "bg", "Лодка за пикник", "Корабни останки")
worldmap_addDesc("party1", "sv", "Picknickbåten", "Skeppsvrak")
worldmap_addDesc("party1", "sl", "Ladja za piknik", "Ladijske razbitine")
worldmap_addDesc("party1", "pt_BR", "Pique-nique no Barco", "Destroços do Navio")
worldmap_addDesc("party1", "ru", "Лодка для пикника", "Кораблекрушения")

worldmap_addDesc("elk", "en", "Great War", "Ship Wrecks")
worldmap_addDesc("elk", "cs", "Velká vlastenecká válka", "Vrakoviště")
worldmap_addDesc("elk", "fr", "La grande guerre", "Les épaves")
worldmap_addDesc("elk", "de", "Erster Weltkrieg", "Schiffswracks")
worldmap_addDesc("elk", "it", "La Grande Guerra", "Navi fracassate")
worldmap_addDesc("elk", "pl", "Wojna Światowa", "Cmentarzysko statków")
worldmap_addDesc("elk", "es", "Gran Guerra", "Ruinas del Barco")
worldmap_addDesc("elk", "nl", "De Eerste Wereldoorlog", "Scheepswrakken")
worldmap_addDesc("elk", "bg", "Световната война", "Корабни останки")
worldmap_addDesc("elk", "sv", "Världskriget", "Skeppsvrak")
worldmap_addDesc("elk", "sl", "Velika vojna", "Ladijske razbitine")
worldmap_addDesc("elk", "pt_BR", "A Grande Guerra", "Destroços do Navio")
worldmap_addDesc("elk", "ru", "Великая война", "Кораблекрушения")

worldmap_addDesc("wreck", "en", "The Ship of Captain Silver", "Ship Wrecks")
worldmap_addDesc("wreck", "cs", "Loď kapitána Silvera", "Vrakoviště")
worldmap_addDesc("wreck", "fr", "Le navire du Capitaine Silver", "Les épaves")
worldmap_addDesc("wreck", "de", "Das Schiff von Kapitän Silver", "Schiffswracks")
worldmap_addDesc("wreck", "it", "La nave di Capitan Silver", "Navi fracassate")
worldmap_addDesc("wreck", "pl", "Statek Kapitana Silvera", "Cmentarzysko statków")
worldmap_addDesc("wreck", "es", "El Barco del Capitán Silver", "Ruinas del Barco")
worldmap_addDesc("wreck", "nl", "Het schip van Kapitein Silver", "Scheepswrakken")
worldmap_addDesc("wreck", "bg", "Корабът на капитан Силвър", "Корабни останки")
worldmap_addDesc("wreck", "sv", "Kapten Silvers skepp", "Skeppsvrak")
worldmap_addDesc("wreck", "sl", "Ladja Kapitana Srebra", "Ladijske razbitine")
worldmap_addDesc("wreck", "pt_BR", "O Navio do Capitão Silver", "Destroços do Navio")
worldmap_addDesc("wreck", "ru", "Корабль капитана Сильвера", "Кораблекрушения")

worldmap_addDesc("viking1", "en", "The Last Voyage", "Ship Wrecks")
worldmap_addDesc("viking1", "cs", "Poslední plavba", "Vrakoviště")
worldmap_addDesc("viking1", "fr", "Le dernier voyage", "Les épaves")
worldmap_addDesc("viking1", "de", "Die letzte Reise", "Schiffswracks")
worldmap_addDesc("viking1", "it", "L'ultimo viaggio", "Navi fracassate")
worldmap_addDesc("viking1", "pl", "Ostatnia podróż", "Cmentarzysko statków")
worldmap_addDesc("viking1", "es", "El Ultimo Viaje", "Ruinas del Barco")
worldmap_addDesc("viking1", "nl", "De laatste reis", "Scheepswrakken")
worldmap_addDesc("viking1", "bg", "Последното пътешествие", "Корабни останки")
worldmap_addDesc("viking1", "sv", "Den sista färden", "Skeppsvrak")
worldmap_addDesc("viking1", "sl", "Zadnje potovanje", "Ladijske razbitine")
worldmap_addDesc("viking1", "pt_BR", "A Última Viagem", "Destroços do Navio")
worldmap_addDesc("viking1", "ru", "Последнее путешествие", "Кораблекрушения")

worldmap_addDesc("airplane", "en", "Altitude: Minus 9000 Feet", "Ship Wrecks")
worldmap_addDesc("airplane", "cs", "Výška: -9000 stop", "Vrakoviště")
worldmap_addDesc("airplane", "fr", "Altitude: moins 9000 pieds", "Les épaves")
worldmap_addDesc("airplane", "de", "Höhe: Minus 3000 Meter", "Schiffswracks")
worldmap_addDesc("airplane", "it", "Altitudine: meno 9000 piedi", "Navi fracassate")
worldmap_addDesc("airplane", "pl", "Wysokość: minus 9000 stóp", "Cmentarzysko statków")
worldmap_addDesc("airplane", "es", "Altitud: Bajo 3000 Metros", "Ruinas del Barco")
worldmap_addDesc("airplane", "nl", "Hoogte: min 3000 meter", "Scheepswrakken")
worldmap_addDesc("airplane", "bg", "Височина: минус 3000 метра", "Корабни останки")
worldmap_addDesc("airplane", "sv", "Altitud: minus 9000 fot", "Skeppsvrak")
worldmap_addDesc("airplane", "sl", "Nadmorska višina: -3000 metrov", "Ladijske razbitine")
worldmap_addDesc("airplane", "pt_BR", "Altitude: -2.740 metros", "Destroços do Navio")
worldmap_addDesc("airplane", "ru", "Высота — минус 3000 метров", "Кораблекрушения")

worldmap_addDesc("bathyscaph", "en", "Bathyscaph", "Ship Wrecks")
worldmap_addDesc("bathyscaph", "cs", "Batyskaf", "Vrakoviště")
worldmap_addDesc("bathyscaph", "fr", "Bathyscaphe", "Les épaves")
worldmap_addDesc("bathyscaph", "de", "Tauchboot", "Schiffswracks")
worldmap_addDesc("bathyscaph", "it", "Batiscafo", "Navi fracassate")
worldmap_addDesc("bathyscaph", "pl", "Batyskaf", "Cmentarzysko statków")
worldmap_addDesc("bathyscaph", "es", "Batiscafo", "Ruinas del Barco")
worldmap_addDesc("bathyscaph", "nl", "Bathyscaaf", "Scheepswrakken")
worldmap_addDesc("bathyscaph", "bg", "Батискаф", "Корабни останки")
worldmap_addDesc("bathyscaph", "sv", "Batyskaf", "Skeppsvrak")
worldmap_addDesc("bathyscaph", "sl", "Batiskaf", "Ladijske razbitine")
worldmap_addDesc("bathyscaph", "pt_BR", "Submerso", "Destroços do Navio")
worldmap_addDesc("bathyscaph", "ru", "Батискаф", "Кораблекрушения")

worldmap_addDesc("tank", "en", "Amphibious Tank", "Ship Wrecks")
worldmap_addDesc("tank", "cs", "Obojživelný tank", "Vrakoviště")
worldmap_addDesc("tank", "fr", "Le char amphibie", "Les épaves")
worldmap_addDesc("tank", "de", "Schwimmpanzer", "Schiffswracks")
worldmap_addDesc("tank", "it", "Carro anfibio", "Navi fracassate")
worldmap_addDesc("tank", "pl", "Amfibia", "Cmentarzysko statków")
worldmap_addDesc("tank", "es", "Tanque Anfibio", "Ruinas del Barco")
worldmap_addDesc("tank", "nl", "Amfibievoertuig", "Scheepswrakken")
worldmap_addDesc("tank", "bg", "Танкът - амфибия", "Корабни останки")
worldmap_addDesc("tank", "sv", "Amfibietank", "Skeppsvrak")
worldmap_addDesc("tank", "sl", "Amfibijski tank", "Ladijske razbitine")
worldmap_addDesc("tank", "pt_BR", "Tanque Anfíbio", "Destroços do Navio")
worldmap_addDesc("tank", "ru", "Танк-амфибия", "Кораблекрушения")

worldmap_addDesc("viking2", "en", "Eight Vikings in a Boat", "Ship Wrecks")
worldmap_addDesc("viking2", "cs", "Osm vikingů a pes", "Vrakoviště")
worldmap_addDesc("viking2", "fr", "Huit vikings dans un bateau", "Les épaves")
worldmap_addDesc("viking2", "de", "Acht Wikinger in einem Boot", "Schiffswracks")
worldmap_addDesc("viking2", "it", "Otto vichinghi in una barca", "Navi fracassate")
worldmap_addDesc("viking2", "pl", "Ośmiu wikingów w łodzi", "Cmentarzysko statków")
worldmap_addDesc("viking2", "es", "Ocho Vikingos en un Bote", "Ruinas del Barco")
worldmap_addDesc("viking2", "nl", "Acht vikingen in een boot", "Scheepswrakken")
worldmap_addDesc("viking2", "bg", "Осем викинги в една лодка", "Корабни останки")
worldmap_addDesc("viking2", "sv", "Åtta vikingar i en båt", "Skeppsvrak")
worldmap_addDesc("viking2", "sl", "Osem vikingov v čolnu", "Ladijske razbitine")
worldmap_addDesc("viking2", "pt_BR", "Oito Vikings em um Navio", "Destroços do Navio")
worldmap_addDesc("viking2", "ru", "Восемь викингов в лодке", "Кораблекрушение")

worldmap_addDesc("party2", "en", "Return from the Party", "Ship Wrecks")
worldmap_addDesc("party2", "cs", "Návrat z výletu", "Vrakoviště")
worldmap_addDesc("party2", "fr", "Retour de la fête", "Les épaves")
worldmap_addDesc("party2", "de", "Rückkehr von der Feier", "Schiffswracks")
worldmap_addDesc("party2", "it", "Ritorno dalla festa", "Navi fracassate")
worldmap_addDesc("party2", "pl", "Powrót z imprezy", "Cmentarzysko statków")
worldmap_addDesc("party2", "es", "Regreso de la Fiesta", "Ruinas del Barco")
worldmap_addDesc("party2", "nl", "Terugkeer van het feest", "Scheepswrakken")
worldmap_addDesc("party2", "bg", "Завръщане от партито", "Корабни останки")
worldmap_addDesc("party2", "sv", "Hem efter festen", "Skeppsvrak")
worldmap_addDesc("party2", "sl", "Vrnitev z zabave", "Ladijske razbitine")
worldmap_addDesc("party2", "pt_BR", "Retorno da Festa", "Destroços do Navio")
worldmap_addDesc("party2", "ru", "Возвращение с вечеринки", "Кораблекрушения")

worldmap_addDesc("gods", "en", "The Gods Must Be Mad", "Ship Wrecks")
worldmap_addDesc("gods", "cs", "Bohové musí být šílení", "Vrakoviště")
worldmap_addDesc("gods", "fr", "Les dieux doivent être fou", "Les épaves")
worldmap_addDesc("gods", "de", "Die Götter müssen verrückt sein", "Schiffswracks")
worldmap_addDesc("gods", "it", "Gli Dei devono essere impazziti", "Navi fracassate")
worldmap_addDesc("gods", "pl", "Bogowie muszą być szaleni", "Cmentarzysko statków")
worldmap_addDesc("gods", "es", "Los Dioses Deben de Estar Locos", "Ruinas del Barco")
worldmap_addDesc("gods", "nl", "De goden zijn gek", "Scheepswrakken")
worldmap_addDesc("gods", "bg", "Боговете сигурно са полудели", "Корабни останки")
worldmap_addDesc("gods", "sv", "Gudarna måste vara tokiga", "Skeppsvrak")
worldmap_addDesc("gods", "sl", "Bogovi morajo biti noriu", "Ladijske razbitine")
worldmap_addDesc("gods", "pt_BR", "Os Deuses devem estar loucos", "Destroços do Navio")
worldmap_addDesc("gods", "ru", "Боги, должно быть, безумны", "Кораблекрушения")

worldmap_addDesc("elevator1", "en", "House with an Elevator", "City In the Deep")
worldmap_addDesc("elevator1", "cs", "Dům s výtahem", "Město v hlubinách")
worldmap_addDesc("elevator1", "fr", "Maison avec ascenseur", "Citée des profondeurs")
worldmap_addDesc("elevator1", "de", "Haus mit einem Fahrstuhl", "Stadt in der Tiefe")
worldmap_addDesc("elevator1", "it", "Casa con ascensore", "Città profonda")
worldmap_addDesc("elevator1", "pl", "Dom z windą", "Miasto w głębinach")
worldmap_addDesc("elevator1", "es", "Casa con Ascensor", "Ciudad en lo Profundo")
worldmap_addDesc("elevator1", "nl", "Huis met een lift", "De verzonken stad")
worldmap_addDesc("elevator1", "bg", "Къща с асансьор", "Потъналият град")
worldmap_addDesc("elevator1", "sv", "Hus med en hiss", "Staden i djupet")
worldmap_addDesc("elevator1", "sl", "Hiša z dvigalom", "Mesto v Globini")
worldmap_addDesc("elevator1", "pt_BR", "A Casa do Elevador", "Destroços do Navio")
worldmap_addDesc("elevator1", "ru", "Дом с лифтом", "Город на глубине")

worldmap_addDesc("city", "en", "Welcome To Our City", "City In the Deep")
worldmap_addDesc("city", "cs", "Vítejte ve městě!", "Město v hlubinách")
worldmap_addDesc("city", "fr", "Bienvenue dans notre cité", "Citée des profondeurs")
worldmap_addDesc("city", "de", "Willkommen in unserer Stadt", "Stadt in der Tiefe")
worldmap_addDesc("city", "it", "Benvenuti nella nostra città", "Città profonda")
worldmap_addDesc("city", "pl", "Witajcie w naszym mieście", "Miasto w głębinach")
worldmap_addDesc("city", "es", "Bienvenido a nuestra Ciudad", "Ciudad en lo Profundo")
worldmap_addDesc("city", "nl", "Welkom in onze stad", "De verzonken stad")
worldmap_addDesc("city", "bg", "Добре дошли в нашия град", "Потъналият град")
worldmap_addDesc("city", "sv", "Välkommen till vår stad", "Staden i djupet")
worldmap_addDesc("city", "sl", "Dobrodošli v našem mestu", "Mesto v Globini")
worldmap_addDesc("city", "pt_BR", "Bem vindo à Nossa Cidade", "A Cidade Profunda")
worldmap_addDesc("city", "ru", "Добро пожаловать в наш город", "Город на глубине")

worldmap_addDesc("ufo", "en", "Independence Day", "City In the Deep")
worldmap_addDesc("ufo", "cs", "Den nezávislosti", "Město v hlubinách")
worldmap_addDesc("ufo", "fr", "Jour d'indépendance", "Citée des profondeurs")
worldmap_addDesc("ufo", "de", "Unabhängigkeitstag", "Stadt in der Tiefe")
worldmap_addDesc("ufo", "it", "Independence Day", "Città profonda")
worldmap_addDesc("ufo", "pl", "Dzień Niepodległości", "Miasto w głebinach")
worldmap_addDesc("ufo", "es", "Día de la Independencia", "Ciudad en lo Profundo")
worldmap_addDesc("ufo", "nl", "Independence Day", "De verzonken stad")
worldmap_addDesc("ufo", "bg", "Денят на независимостта", "Потъналият град")
worldmap_addDesc("ufo", "sv", "Självständighetsdagen", "Staden i djupet")
worldmap_addDesc("ufo", "sl", "Dan neodvisnosti", "Mesto v Globini")
worldmap_addDesc("ufo", "pt_BR", "Dia da Independência", "A Cidade Profunda")
worldmap_addDesc("ufo", "ru", "День независимости", "Город на глубине")

worldmap_addDesc("columns", "en", "The Columns", "City In the Deep")
worldmap_addDesc("columns", "cs", "Na kolonádě", "Město v hlubinách")
worldmap_addDesc("columns", "fr", "Les colonnes", "Citée des profondeurs")
worldmap_addDesc("columns", "de", "Die Säulen", "Stadt in der Tiefe")
worldmap_addDesc("columns", "it", "Le colonne", "Città profonda")
worldmap_addDesc("columns", "pl", "Kolumny", "Miasto w głębinach")
worldmap_addDesc("columns", "es", "Las Columnas", "Ciudad en lo Profundo")
worldmap_addDesc("columns", "nl", "De pilaren", "De verzonken stad")
worldmap_addDesc("columns", "bg", "Колоните", "Потъналият град")
worldmap_addDesc("columns", "sv", "Pelarna", "Staden i djupet")
worldmap_addDesc("columns", "sl", "Stebri", "Mesto v Globini")
worldmap_addDesc("columns", "pt_BR", "As Colunas", "A Cidade Profunda")
worldmap_addDesc("columns", "ru", "Колонны", "Город на глубине")

worldmap_addDesc("pavement", "en", "Uneven Pavement", "City In the Deep")
worldmap_addDesc("pavement", "cs", "Nerovná dlažba", "Město v hlubinách")
worldmap_addDesc("pavement", "fr", "Chaussée abîmée", "Citée des profondeurs")
worldmap_addDesc("pavement", "de", "Unebener Bürgersteig", "Stadt in der Tiefe")
worldmap_addDesc("pavement", "it", "Pavimento sconnesso", "Città profonda")
worldmap_addDesc("pavement", "pl", "Nierówny chodnik", "Miasto w głębinach")
worldmap_addDesc("pavement", "es", "Pavimento en Desnivel", "Ciudad en lo Profundo")
worldmap_addDesc("pavement", "nl", "Hobbelig trottoir", "De verzonken stad")
worldmap_addDesc("pavement", "bg", "Неравен паваж", "Потъналият град")
worldmap_addDesc("pavement", "sv", "Ojämn trottoar", "Staden i djupet")
worldmap_addDesc("pavement", "sl", "Neraven pločnik", "Mesto v Globini")
worldmap_addDesc("pavement", "pt_BR", "Pavimento Irregular", "A Cidade Profunda")
worldmap_addDesc("pavement", "ru", "Неровный тротуар", "Город на глубине")

worldmap_addDesc("pyramid", "en", "Mr. Cheops’ House", "City In the Deep")
worldmap_addDesc("pyramid", "cs", "Dům pana Cheopse", "Město v hlubinách")
worldmap_addDesc("pyramid", "fr", "Chez Mr. Kheops", "Citée des profondeurs")
worldmap_addDesc("pyramid", "de", "Das Haus des Herrn Cheops", "Stadt in der Tiefe")
worldmap_addDesc("pyramid", "it", "La casa del Sig. Cheope", "Città profonda")
worldmap_addDesc("pyramid", "pl", "Dom pana Cheopsa", "Miasto w głębinach")
worldmap_addDesc("pyramid", "es", "La Casa de Mr. Cheops", "Ciudad en lo Profundo")
worldmap_addDesc("pyramid", "nl", "Het huis van Cheops", "De verzonken stad")
worldmap_addDesc("pyramid", "bg", "Къщата на г-н Хеопс", "Потъналият град")
worldmap_addDesc("pyramid", "sv", "Cheops hus", "Staden i djupet")
worldmap_addDesc("pyramid", "sl", "Keopsova hiša", "Mesto v Globini")
worldmap_addDesc("pyramid", "pt_BR", "A Casa do Sr. Cheops", "A Cidade Profunda")
worldmap_addDesc("pyramid", "ru", "Дом мистера Хеопса", "Город на глубине")

worldmap_addDesc("music", "en", "A Bit of Music", "City In the Deep")
worldmap_addDesc("music", "cs", "Pro potěšení", "Město v hlubinách")
worldmap_addDesc("music", "fr", "Une note de musique", "Citée des profondeurs")
worldmap_addDesc("music", "de", "Ein bisschen Musik", "Stadt in der Tiefe")
worldmap_addDesc("music", "it", "Un po' di musica", "Città profonda")
worldmap_addDesc("music", "pl", "Nieco muzyki", "Miasto w głebinach")
worldmap_addDesc("music", "es", "Un Poco de Música", "Ciudad en lo Profundo")
worldmap_addDesc("music", "nl", "Een beetje muziek", "De verzonken stad")
worldmap_addDesc("music", "bg", "Малко музика", "Потъналият град")
worldmap_addDesc("music", "sv", "Lite musik", "Staden i djupet")
worldmap_addDesc("music", "sl", "Malo glasbe", "Mesto v Globini")
worldmap_addDesc("music", "pt_BR", "Um Pouco de Música", "A Cidade Profunda")
worldmap_addDesc("music", "ru", "Немного музыки", "Город на глубине")

worldmap_addDesc("crabshow", "en", "Crab Freak Show", "City In the Deep")
worldmap_addDesc("crabshow", "cs", "Panoptikum korýšů", "Město v hlubinách")
worldmap_addDesc("crabshow", "fr", "La danse des crabes", "Citée des profondeurs")
worldmap_addDesc("crabshow", "de", "Krabben-Monster-Schau", "Stadt in der Tiefe")
worldmap_addDesc("crabshow", "it", "Granchi da baraccone", "Città profonda")
worldmap_addDesc("crabshow", "pl", "Krabie muzeum osobliwości", "Miasto w głębinach")
worldmap_addDesc("crabshow", "es", "Loco Show del Cangrejo", "Ciudad en lo Profundo")
worldmap_addDesc("crabshow", "nl", "Krabbenrariteitenkabinet", "De verzonken stad")
worldmap_addDesc("crabshow", "bg", "Шоуто на лудия рак", "Потъналият град")
worldmap_addDesc("crabshow", "sv", "Krabbmonstershow", "Staden i djupet")
worldmap_addDesc("crabshow", "sl", "Razstava rakovskih spak", "Mesto v Globini")
worldmap_addDesc("crabshow", "pt_BR", "Show Maluco do Caranguejo", "A Cidade Profunda")
worldmap_addDesc("crabshow", "ru", "Шоу причудливых крабов", "Город на глубине")

worldmap_addDesc("elevator2", "en", "Another elevator", "City In the Deep")
worldmap_addDesc("elevator2", "cs", "Druhý dům s výtahem", "Město v hlubinách")
worldmap_addDesc("elevator2", "fr", "Un autre ascenseur", "Citée des profondeurs")
worldmap_addDesc("elevator2", "de", "Noch ein Fahrstuhl", "Stadt in der Tiefe")
worldmap_addDesc("elevator2", "it", "Un altro ascensore", "Città profonda")
worldmap_addDesc("elevator2", "pl", "Jeszcze jedna winda", "Miasto w głębinach")
worldmap_addDesc("elevator2", "es", "Otro Ascensor", "Ciudad en lo Profundo")
worldmap_addDesc("elevator2", "nl", "Nog een lift", "De verzonken stad")
worldmap_addDesc("elevator2", "bg", "Още един асаньор", "Потъналият град")
worldmap_addDesc("elevator2", "sv", "Ännu en hiss", "Staden i djupet")
worldmap_addDesc("elevator2", "sl", "Še eno dvigalo", "Mesto v Globini")
worldmap_addDesc("elevator2", "pt_BR", "Outro Elevador", "A Cidade Profunda")
worldmap_addDesc("elevator2", "ru", "Еще один лифт", "Город на глубине")

worldmap_addDesc("atlantis", "en", "And How It Was", "City In the Deep")
worldmap_addDesc("atlantis", "cs", "Tak takhle to bylo", "Město v hlubinách")
worldmap_addDesc("atlantis", "fr", "Comment ce fut",  "Citée des profondeurs")
worldmap_addDesc("atlantis", "de", "Wie es war",  "Stadt in der Tiefe")
worldmap_addDesc("atlantis", "it", "L'arcano svelato", "Città profonda")
worldmap_addDesc("atlantis", "pl", "Tak to było", "Miasto w głębinach")
worldmap_addDesc("atlantis", "es", "Y Cómo Era",  "Ciudad en lo Profundo")
worldmap_addDesc("atlantis", "nl", "Hoe het zat",  "De verzonken stad")
worldmap_addDesc("atlantis", "bg", "Така беше едно време", "Потъналият град")
worldmap_addDesc("atlantis", "sv", "Som det var", "Staden i djupet")
worldmap_addDesc("atlantis", "sl", "Kako je bilo", "Mesto v Globini")
worldmap_addDesc("atlantis", "pt_BR", "E Como Era", "A Cidade Profunda")
worldmap_addDesc("atlantis", "ru", "Вот как это было",  "Город на глубине")

worldmap_addDesc("corals", "en", "First Bizarre Things", "Coral reef")
worldmap_addDesc("corals", "cs", "První bizarnosti", "Korálový útes")
worldmap_addDesc("corals", "fr", "Première chose bizarre", "Récif de corail")
worldmap_addDesc("corals", "de", "Erste bizarre Dinge", "Korallenriff")
worldmap_addDesc("corals", "it", "Le prime bizzarrie", "Barriera corallina")
worldmap_addDesc("corals", "pl", "Pierwsze dziwy", "Rafa koralowa")
worldmap_addDesc("corals", "es", "Primeras cosas Bizarras", "Arrecife de Coral")
worldmap_addDesc("corals", "nl", "De eerste bizarre dingen", "Koraalrif")
worldmap_addDesc("corals", "bg", "Първите странни неща", "Коралов риф")
worldmap_addDesc("corals", "sv", "Första bisarra saken", "Korallrev")
worldmap_addDesc("corals", "pt_BR", "Primeiras Coisas Bizarras", "Recife de Corais")
worldmap_addDesc("corals", "ru", "Первый безумный предмет", "Коралловый риф")

worldmap_addDesc("labyrinth", "en", "Labyrinth", "Coral reef")
worldmap_addDesc("labyrinth", "cs", "Bludiště", "Korálový útes")
worldmap_addDesc("labyrinth", "fr", "Labyrinthe", "Récif de corail")
worldmap_addDesc("labyrinth", "de", "Labyrinth", "Korallenriff")
worldmap_addDesc("labyrinth", "it", "Labirinto", "Barriera corallina")
worldmap_addDesc("labyrinth", "pl", "Labirynt", "Rafa koralowa")
worldmap_addDesc("labyrinth", "es", "Laberinto", "Arrecife de Coral")
worldmap_addDesc("labyrinth", "nl", "Labyrint", "Koraalrif")
worldmap_addDesc("labyrinth", "bg", "Лабиринт", "Коралов риф")
worldmap_addDesc("labyrinth", "sv", "Labyrinten", "Korallrev")
worldmap_addDesc("labyrinth", "pt_BR", "Labirinto", "Recife de Corais")
worldmap_addDesc("labyrinth", "ru", "Лабиринт", "Коралловый риф")

worldmap_addDesc("imprisoned", "en", "Imprisoned", "Coral reef")
worldmap_addDesc("imprisoned", "cs", "Uvězněni", "Korálový útes")
worldmap_addDesc("imprisoned", "fr", "En prison", "Récif de corail")
worldmap_addDesc("imprisoned", "de", "Gefangen", "Korallenriff")
worldmap_addDesc("imprisoned", "it", "Imprigionati", "Barriera corallina")
worldmap_addDesc("imprisoned", "pl", "Uwięzieni", "Rafa koralowa")
worldmap_addDesc("imprisoned", "es", "En Prisión", "Arrecife de Coral")
worldmap_addDesc("imprisoned", "nl", "Gevangen", "Koraalrif")
worldmap_addDesc("imprisoned", "bg", "Затворени", "Коралов риф")
worldmap_addDesc("imprisoned", "sv", "Fängslad", "Korallrev")
worldmap_addDesc("imprisoned", "pt_BR", "Preso", "Recife de Corais")
worldmap_addDesc("imprisoned", "ru", "Заключённые", "Коралловый риф")

worldmap_addDesc("society", "en", "Closed Society", "Coral reef")
worldmap_addDesc("society", "cs", "Uzavřená společnost", "Korálový útes")
worldmap_addDesc("society", "fr", "Société fermée", "Récif de corail")
worldmap_addDesc("society", "de", "Geschlossene Gesellschaft", "Korallenriff")
worldmap_addDesc("society", "it", "Società chiusa", "Barriera corallina")
worldmap_addDesc("society", "pl", "Zamknięta społeczność", "Rafa koralowa")
worldmap_addDesc("society", "es", "Sociedad Cerrada", "Arrecife de Coral")
worldmap_addDesc("society", "nl", "Besloten gezelschap", "Koraalrif")
worldmap_addDesc("society", "bg", "Затворено общество", "Коралов риф")
worldmap_addDesc("society", "sv", "Slutet sällskap", "Korallrev")
worldmap_addDesc("society", "pt_BR", "Sociedade Fechada", "Recife de Corais")
worldmap_addDesc("society", "ru", "Закрытое общество", "Коралловый риф")

worldmap_addDesc("creatures", "en", "Sleeping Creatures", "Coral reef")
worldmap_addDesc("creatures", "cs", "Spící tvorečkové", "Korálový útes")
worldmap_addDesc("creatures", "fr", "Créatures dormantes", "Récif de corail")
worldmap_addDesc("creatures", "de", "Schlafende Wesen", "Korallenriff")
worldmap_addDesc("creatures", "it", "Creature dormienti", "Barriera corallina")
worldmap_addDesc("creatures", "pl", "Śpiące stworzenia", "Rafa koralowa")
worldmap_addDesc("creatures", "es", "Criaturas Durmientes", "Arrecife de Coral")
worldmap_addDesc("creatures", "nl", "Slapende diertjes", "Koraalrif")
worldmap_addDesc("creatures", "bg", "Спящи създания", "Коралов риф")
worldmap_addDesc("creatures", "sv", "Sovande djur", "Korallrev")
worldmap_addDesc("creatures", "pt_BR", "Criaturas Adormecidas", "Recife de Corais")
worldmap_addDesc("creatures", "ru", "Спящие существа", "Коралловый риф")

worldmap_addDesc("cancan", "en", "Cancan Crabs", "Coral reef")
worldmap_addDesc("cancan", "cs", "Kankánoví krabíci", "Korálový útes")
worldmap_addDesc("cancan", "fr", "Le cancan des crabes", "Récif de corail")
worldmap_addDesc("cancan", "de", "Cancan-Krabben", "Korallenriff")
worldmap_addDesc("cancan", "it", "Cancan Crabs", "Barriera corallina")
worldmap_addDesc("cancan", "pl", "Kankanowe kraby", "Rafa koralowa")
worldmap_addDesc("cancan", "es", "Cangrejos Cancan", "Arrecife de Coral")
worldmap_addDesc("cancan", "nl", "Cancan-krabben", "Koraalrif")
worldmap_addDesc("cancan", "bg", "Раци кан-кан", "Коралов риф")
worldmap_addDesc("cancan", "sv", "Cancankrabbor", "Korallrev")
worldmap_addDesc("cancan", "pt_BR", "Dança do Caranguejo", "Recife de Corais")
worldmap_addDesc("cancan", "ru", "Крабий канкан", "Коралловый риф")

worldmap_addDesc("pearls", "en", "One More Pearl; Please!", "Coral reef")
worldmap_addDesc("pearls", "cs", "Ještě jednu perličku!", "Korálový útes")
worldmap_addDesc("pearls", "fr", "Une perle de plus; s'il vous plaît !", "Récif de corail")
worldmap_addDesc("pearls", "de", "Bitte noch eine Perle!", "Korallenriff")
worldmap_addDesc("pearls", "it", "Un'altra perla, per favore!", "Barriera corallina")
worldmap_addDesc("pearls", "pl", "Proszę, jeszcze jedna perła!", "Rafa koralowa")
worldmap_addDesc("pearls", "es", "Una Perla Más; ¡Por Favor!", "Arrecife de Coral")
worldmap_addDesc("pearls", "nl", "Nog een parel, alsjeblieft!", "Koraalrif")
worldmap_addDesc("pearls", "bg", "Още една перла. Моля!", "Коралов риф")
worldmap_addDesc("pearls", "sv", "En till pärla, tack!", "Korallrev")
worldmap_addDesc("pearls", "pt_BR", "Mais uma pérola; Por Favor!", "Recife de Corais")
worldmap_addDesc("pearls", "ru", "Еще одну жемчужину, пожалуйста!", "Коралловый риф")

worldmap_addDesc("turtle", "en", "Telepathic Devil", "Coral reef")
worldmap_addDesc("turtle", "cs", "Telepatická mrcha", "Korálový útes")
worldmap_addDesc("turtle", "fr", "Le diable télépathique", "Récif de corail")
worldmap_addDesc("turtle", "de", "Telepathischer Teufel", "Korallenriff")
worldmap_addDesc("turtle", "it", "Malvagità telepatica", "Barriera corallina")
worldmap_addDesc("turtle", "pl", "Telepatyczny diabeł", "Rafa koralowa")
worldmap_addDesc("turtle", "es", "Diablo Telepático", "Arrecife de Coral")
worldmap_addDesc("turtle", "nl", "Telepathische duivel", "Koraalrif")
worldmap_addDesc("turtle", "bg", "Телепатичен дявол", "Коралов риф")
worldmap_addDesc("turtle", "sv", "Telepatisk djävul", "Korallrev")
worldmap_addDesc("turtle", "pt_BR", "Demônio Telepata", "Recife de Corais")
worldmap_addDesc("turtle", "ru", "Телепатия дьявола", "Коралловый риф")

worldmap_addDesc("computer", "en", "The Deep Server", "Dump")
worldmap_addDesc("computer", "cs", "Hlubinný server", "Smetiště")
worldmap_addDesc("computer", "fr", "Le serveur des profondeurs", "le dépotoir")
worldmap_addDesc("computer", "de", "Der tiefe Server", "Halde")
worldmap_addDesc("computer", "it", "Il Server Profondo", "Pattumiera")
worldmap_addDesc("computer", "pl", "Serwer głębinowy", "Śmietnisko")
worldmap_addDesc("computer", "es", "El Servidor en lo Profundo", "Vertedero")
worldmap_addDesc("computer", "nl", "De diepe server", "Vuilnis")
worldmap_addDesc("computer", "bg", "Дълбокия сървър", "Боклук")
worldmap_addDesc("computer", "sv", "Den djupa servern", "Avfall")
worldmap_addDesc("computer", "pt_BR", "O Servidor Profundo", "Aterro")
worldmap_addDesc("computer", "ru", "Глубоководный сервер", "Свалка")

worldmap_addDesc("noground", "en", "Almost No Wall", "Dump")
worldmap_addDesc("noground", "cs", "Skoro žádná zeď", "Smetiště")
worldmap_addDesc("noground", "fr", "Presque pas de mur", "le dépotoir")
worldmap_addDesc("noground", "de", "Fast keine Wand", "Halde")
worldmap_addDesc("noground", "it", "Quasi senza muri", "Pattumiera")
worldmap_addDesc("noground", "pl", "Prawie bez ścian", "Śmietnisko")
worldmap_addDesc("noground", "es", "Casi Ninguna Muralla", "Vertedero")
worldmap_addDesc("noground", "nl", "Bijna geen muur", "Vuilnis")
worldmap_addDesc("noground", "bg", "Почти без стени", "Боклук")
worldmap_addDesc("noground", "sv", "Nästan inga väggar", "Avfall")
worldmap_addDesc("noground", "pt_BR", "Quase Sem Muro", "Aterro")
worldmap_addDesc("noground", "ru", "Почти без стен", "Свалка")

worldmap_addDesc("bathroom", "en", "Plumbman’s Refuse", "Dump")
worldmap_addDesc("bathroom", "cs", "Instalatérský odpad", "Smetiště")
worldmap_addDesc("bathroom", "fr", "Le refus du bonhomme de plomb", "le dépotoir")
worldmap_addDesc("bathroom", "de", "Der Abfall des Installateurs", "Halde")
worldmap_addDesc("bathroom", "it", "Gli scarti dell'idraulico", "Pattumiera")
worldmap_addDesc("bathroom", "pl", "Odpadki hydrauliczne", "Śmietnisko")
worldmap_addDesc("bathroom", "es", "El Rechazo del Plomero", "Vertedero")
worldmap_addDesc("bathroom", "nl", "Het afval van de loodgieter", "Vuilnis")
worldmap_addDesc("bathroom", "bg", "Отказът на водопроводчика", "Боклук")
worldmap_addDesc("bathroom", "sv", "Rörmokarens avfall", "Avfall")
worldmap_addDesc("bathroom", "pt_BR", "Restos do Encanador", "Aterro")
worldmap_addDesc("bathroom", "ru", "Сантехнический мусор", "Свалка")

worldmap_addDesc("duckie", "en", "Adventure with Pink Duckie", "Dump")
worldmap_addDesc("duckie", "cs", "Dobrodružství s kachničkou", "Smetiště")
worldmap_addDesc("duckie", "fr", "Aventure avec le canard rose", "le dépotoir")
worldmap_addDesc("duckie", "de", "Abenteuer mit Rosa Entlein", "Halde")
worldmap_addDesc("duckie", "it", "Avventura con Paperetta Rosa", "Pattumiera")
worldmap_addDesc("duckie", "pl", "Przygoda z różową kaczuszką", "Śmietnisko")
worldmap_addDesc("duckie", "es", "Aventura con el Patito Rosado", "Vertedero")
worldmap_addDesc("duckie", "nl", "Avontuur met een roze badeendje", "Vuilnis")
worldmap_addDesc("duckie", "bg", "Приключения с розово пате", "Боклук")
worldmap_addDesc("duckie", "sv", "Äventyr med den rosa ankan", "Avfall")
worldmap_addDesc("duckie", "pt_BR", "Aventura com o Patinho Rosa", "Aterro")
worldmap_addDesc("duckie", "ru", "Приключения с розовой уточкой", "Свалка")

worldmap_addDesc("puzzle", "en", "Shredded Stickman", "Dump")
worldmap_addDesc("puzzle", "cs", "Rozstříhaná čmáranice", "Smetiště")
worldmap_addDesc("puzzle", "fr", "Eparpillement", "le dépotoir")
worldmap_addDesc("puzzle", "de", "Ablenkung", "Halde")
worldmap_addDesc("puzzle", "it", "Omino ingarbugliato", "Pattumiera")
worldmap_addDesc("puzzle", "pl", "Podarty bohomaz", "Śmietnisko")
worldmap_addDesc("puzzle", "es", "Dispersión", "Vertedero")
worldmap_addDesc("puzzle", "nl", "Verknipt plaatje", "Vuilnis")
worldmap_addDesc("puzzle", "bg", "Накълцания палач", "Боклук")
worldmap_addDesc("puzzle", "sv", "Utspridd croupier", "Avfall")
worldmap_addDesc("puzzle", "pt_BR", "Distração", "Aterro")
worldmap_addDesc("puzzle", "ru", "Измельчённая картина", "Свалка")

worldmap_addDesc("dump", "en", "Real Chaos", "Dump")
worldmap_addDesc("dump", "cs", "Opravdový chaos", "Smetiště")
worldmap_addDesc("dump", "fr", "Le vrai chaos", "le dépotoir")
worldmap_addDesc("dump", "de", "Echtes Durcheinander", "Halde")
worldmap_addDesc("dump", "it", "Caos totale", "Pattumiera")
worldmap_addDesc("dump", "pl", "Prawdziwy chaos", "Śmietnisko")
worldmap_addDesc("dump", "es", "Caos Real", "Vertedero")
worldmap_addDesc("dump", "nl", "Totale chaos", "Vuilnis")
worldmap_addDesc("dump", "bg", "Истински хаос", "Боклук")
worldmap_addDesc("dump", "sv", "Fullständigt kaos", "Avfall")
worldmap_addDesc("dump", "pt_BR", "Caos Total", "Aterro")
worldmap_addDesc("dump", "ru", "Настоящий хаос", "Свалка")

worldmap_addDesc("barrel", "en", "Outraged Greenpeace", "Dump")
worldmap_addDesc("barrel", "cs", "Greenpeace by zuřili", "Smetiště")
worldmap_addDesc("barrel", "fr", "Greenpeace scandalisé", "le dépotoir")
worldmap_addDesc("barrel", "de", "Empörtes Greenpeace", "Halde")
worldmap_addDesc("barrel", "it", "Greenpeace oltraggiata", "Pattumiera")
worldmap_addDesc("barrel", "pl", "Obraza Greenpeace", "Śmietnisko")
worldmap_addDesc("barrel", "es", "Greenpeace Ultrajado", "Vertedero")
worldmap_addDesc("barrel", "nl", "Boze Greenpeace", "Vuilnis")
worldmap_addDesc("barrel", "bg", "Оскърбен Грийнпийсe", "Боклук")
worldmap_addDesc("barrel", "sv", "Uppretat Greenpeace", "Avfall")
worldmap_addDesc("barrel", "pt_BR", "Greenpeace Revoltado", "Aterro")
worldmap_addDesc("barrel", "ru", "Оскорблённый «Гринпис»", "Свалка")

worldmap_addDesc("cabin1", "en", "The First Mate’s Cabin", "Silver's Ship")
worldmap_addDesc("cabin1", "cs", "Kajuta prvního důstojníka", "Silverova loď")
worldmap_addDesc("cabin1", "fr", "La cabine du premier matelot", "Le navire de Silver")
worldmap_addDesc("cabin1", "de", "Die Kajüte des ersten Offiziers", "Silvers Schiff")
worldmap_addDesc("cabin1", "it", "La cabina del primo ufficiale", "La nave di Silver")
worldmap_addDesc("cabin1", "pl", "Kajuta pierwszego mata", "Statek Silvera")
worldmap_addDesc("cabin1", "es", "La Cabina del Primer Oficial", "El Barco de Silver")
worldmap_addDesc("cabin1", "nl", "De hut van de eerste officier", "Het schip van Kapitein Silver")
worldmap_addDesc("cabin1", "bg", "Каютата на първия помощник", "Корабът на Силвър")
worldmap_addDesc("cabin1", "sv", "Förste officerens hytt", "Silvers skepp")
worldmap_addDesc("cabin1", "pt_BR", "A Cabine do Primeiro Oficial", "O Navio de Silver")
worldmap_addDesc("cabin1", "ru", "Каюта первого помощника", "Корабль Сильвера")

worldmap_addDesc("snowman", "en", "The Winter Mess Hall", "Silver's Ship")
worldmap_addDesc("snowman", "cs", "Zimní jídelna", "Silverova loď")
worldmap_addDesc("snowman", "fr", "Le salon d'hiver", "Le navire de Silver")
worldmap_addDesc("snowman", "de", "Die Wintermesse", "Silvers Schiff")
worldmap_addDesc("snowman", "it", "Mensa Invernale", "La nave di Silver")
worldmap_addDesc("snowman", "pl", "Zimowa mesa", "Statek Silvera")
worldmap_addDesc("snowman", "es", "El Lío en el Salón de Invierno", "El Barco de Silver")
worldmap_addDesc("snowman", "nl", "De winterkajuit", "Het schip van Kapitein Silver")
worldmap_addDesc("snowman", "bg", "Зимна бъркотия", "Корабът на Силвър")
worldmap_addDesc("snowman", "sv", "Vintermässen", "Silvers skepp")
worldmap_addDesc("snowman", "pt_BR", "A Bagunça no Salão de Inverno", "O Navio de Silver")
worldmap_addDesc("snowman", "ru", "Зимняя столовая", "Корабль Сильвера")

worldmap_addDesc("cannons", "en", "Fire!", "Silver's Ship")
worldmap_addDesc("cannons", "cs", "Pal!", "Silverova loď")
worldmap_addDesc("cannons", "fr", "Feu !", "Le navire de Silver")
worldmap_addDesc("cannons", "de", "Feuer!", "Silvers Schiff")
worldmap_addDesc("cannons", "it", "Fuoco!", "La nave di Silver")
worldmap_addDesc("cannons", "pl", "Ognia!", "Statek Silvera")
worldmap_addDesc("cannons", "es", "Fuego!", "El Barco de Silver")
worldmap_addDesc("cannons", "nl", "Vuur!", "Het schip van Kapitein Silver")
worldmap_addDesc("cannons", "bg", "Пожар!", "Корабът на Силвър")
worldmap_addDesc("cannons", "sv", "Eld!", "Silvers skepp")
worldmap_addDesc("cannons", "pt_BR", "Fogo!", "O Navio de Silver")
worldmap_addDesc("cannons", "ru", "Пожар!", "Корабль Сильвера")

worldmap_addDesc("kitchen", "en", "Ship Kitchen", "Silver's Ship")
worldmap_addDesc("kitchen", "cs", "Lodní kuchyně", "Silverova loď")
worldmap_addDesc("kitchen", "fr", "La cuisine du navire", "Le navire de Silver")
worldmap_addDesc("kitchen", "de", "Schiffsküche", "Silvers Schiff")
worldmap_addDesc("kitchen", "it", "La cucina di bordo", "La nave di Silver")
worldmap_addDesc("kitchen", "pl", "Kuchnia okrętowa", "Statek Silvera")
worldmap_addDesc("kitchen", "es", "Cocina del Barco", "El Barco de Silver")
worldmap_addDesc("kitchen", "nl", "De kombuis", "Het schip van Kapitein Silver")
worldmap_addDesc("kitchen", "bg", "Корабната кухня", "Корабът на Силвър")
worldmap_addDesc("kitchen", "sv", "Skeppsköket", "Silvers skepp")
worldmap_addDesc("kitchen", "pt_BR", "A Cozinha do Navio", "O Navio de Silver")
worldmap_addDesc("kitchen", "ru", "Камбуз", "Корабль Сильвера")

worldmap_addDesc("cabin2", "en", "Second Mate’s Cabin", "Silver's Ship")
worldmap_addDesc("cabin2", "cs", "Kajuta druhého důstojníka", "Silverova loď")
worldmap_addDesc("cabin2", "fr", "La cabine du second", "Le navire de Silver")
worldmap_addDesc("cabin2", "de", "Die Kajüte des zweiten Offiziers", "Silvers Schiff")
worldmap_addDesc("cabin2", "it", "La cabina dell'ufficiale in seconda", "La nave di Silver")
worldmap_addDesc("cabin2", "pl", "Kajuta drugiego mata", "Statek Silvera")
worldmap_addDesc("cabin2", "es", "La Cabina del Segundo Oficial", "El Barco de Silver")
worldmap_addDesc("cabin2", "nl", "De hut van de tweede officier", "Het schip van Kapitein Silver")
worldmap_addDesc("cabin2", "bg", "Каютата на втория помощник", "Корабът на Силвър")
worldmap_addDesc("cabin2", "sv", "Andre officerens hytt", "Silvers skepp")
worldmap_addDesc("cabin2", "pt_BR", "A Cabine do Segundo Oficial", "O Navio de Silver")
worldmap_addDesc("cabin2", "ru", "Каюта второго помощника", "Корабль Сильвера")

worldmap_addDesc("captain", "en", "Captain’s Cabin", "Silver's Ship")
worldmap_addDesc("captain", "cs", "Kapitánova kajuta", "Silverova loď")
worldmap_addDesc("captain", "fr", "La cabine du Capitaine", "Le navire de Silver")
worldmap_addDesc("captain", "de", "Kapitänskajüte", "Silvers Schiff")
worldmap_addDesc("captain", "it", "La cabina del capitano", "La nave di Silver")
worldmap_addDesc("captain", "pl", "Kajuta kapitańska", "Statek Silvera")
worldmap_addDesc("captain", "es", "La Cabina del Capitán", "El Barco de Silver")
worldmap_addDesc("captain", "nl", "De hut van de kapitein", "Het schip van Kapitein Silver")
worldmap_addDesc("captain", "bg", "Каютата на капитана", "Корабът на Силвър")
worldmap_addDesc("captain", "sv", "Kaptens hytt", "Silvers skepp")
worldmap_addDesc("captain", "pt_BR", "A Cabine do Capitão", "O Navio de Silver")
worldmap_addDesc("captain", "ru", "Капитанская каюта", "Корабль Сильвера")

worldmap_addDesc("map", "en", "Silver’s Hideout", "Silver's Ship")
worldmap_addDesc("map", "cs", "Silverova tajná skrýš", "Silverova loď")
worldmap_addDesc("map", "fr", "La cache de Silver", "Le navire de Silver")
worldmap_addDesc("map", "de", "Silvers Versteck", "Silvers Schiff")
worldmap_addDesc("map", "it", "Il nascondiglio di Silver", "La nave di Silver")
worldmap_addDesc("map", "pl", "Kryjówka Silvera", "Statek Silvera")
worldmap_addDesc("map", "es", "El Escondite de Silver", "El Barco de Silver")
worldmap_addDesc("map", "nl", "Silvers geheime plekje", "Het schip van Kapitein Silver")
worldmap_addDesc("map", "bg", "Скривалището на Силвър", "Корабът на Силвър")
worldmap_addDesc("map", "sv", "Silvers gömställe", "Silvers skepp")
worldmap_addDesc("map", "pt_BR", "O Esconderijo de Silver", "O Navio de Silver")
worldmap_addDesc("map", "ru", "Тайник Сильвера", "Корабль Сильвера")

worldmap_addDesc("reactor", "en", "Power Plant", "UFO")
worldmap_addDesc("reactor", "cs", "Reaktor", "Ztroskotané UFO")
worldmap_addDesc("reactor", "fr", "Centrale électrique", "ovni")
worldmap_addDesc("reactor", "de", "Kraftwerk", "UFO")
worldmap_addDesc("reactor", "it", "Centrale elettrica", "UFO")
worldmap_addDesc("reactor", "pl", "Reaktor", "UFO")
worldmap_addDesc("reactor", "es", "Central Eléctrica", "OVNI")
worldmap_addDesc("reactor", "nl", "Reactor", "Vliegende schotel")
worldmap_addDesc("reactor", "bg", "Реактор", "НЛО")
worldmap_addDesc("reactor", "sv", "Reaktor", "UFO")
worldmap_addDesc("reactor", "pt_BR", "Estação de Força", "UFO")
worldmap_addDesc("reactor", "ru", "Электростанция", "НЛО")

worldmap_addDesc("magnet", "en", "Strange Forces", "UFO")
worldmap_addDesc("magnet", "cs", "Neznámé síly", "Ztroskotané UFO")
worldmap_addDesc("magnet", "fr", "Forces étranges", "ovni")
worldmap_addDesc("magnet", "de", "Seltsame Kräfte", "UFO")
worldmap_addDesc("magnet", "it", "Strane forze", "UFO")
worldmap_addDesc("magnet", "pl", "Nieznane siły", "UFO")
worldmap_addDesc("magnet", "es", "Fuerzas Extrañas", "OVNI")
worldmap_addDesc("magnet", "nl", "Vreemde krachten", "Vliegende schotel")
worldmap_addDesc("magnet", "bg", "Странни сили", "НЛО")
worldmap_addDesc("magnet", "sv", "Okända krafter", "UFO")
worldmap_addDesc("magnet", "pt_BR", "Forças Estranhas", "UFO")
worldmap_addDesc("magnet", "ru", "Странные силы", "НЛО")

worldmap_addDesc("engine", "en", "Brm... Brm...", "UFO")
worldmap_addDesc("engine", "cs", "Brm brm...", "Ztroskotané UFO")
worldmap_addDesc("engine", "fr", "Brm... Brm...", "ovni")
worldmap_addDesc("engine", "de", "Brm... Brm...", "UFO")
worldmap_addDesc("engine", "pl", "Brum... Brum...", "UFO")
worldmap_addDesc("engine", "es", "Brm... Brm...", "OVNI")
worldmap_addDesc("engine", "nl", "Vroem... Vroem...", "Vliegende schotel")
worldmap_addDesc("engine", "bg", "Бърм... Бръм...", "НЛО")
worldmap_addDesc("engine", "sv", "Brum... Brum...", "UFO")
worldmap_addDesc("engine", "pt_BR", "Brm... Brm...", "UFO")
worldmap_addDesc("engine", "ru", "Брум... Брум...", "НЛО")

worldmap_addDesc("steel", "en", "Nothing but steel", "UFO")
worldmap_addDesc("steel", "cs", "Ocel; samá ocel", "Ztroskotané UFO")
worldmap_addDesc("steel", "fr", "Rien que du métal", "ovni")
worldmap_addDesc("steel", "de", "Alles nur Stahl", "UFO")
worldmap_addDesc("steel", "it", "Nient'altro che acciaio", "UFO")
worldmap_addDesc("steel", "pl", "Nic, tylko stal", "UFO")
worldmap_addDesc("steel", "es", "Nada mas que Acero", "OVNI")
worldmap_addDesc("steel", "nl", "Alleen maar staal", "Vliegende schotel")
worldmap_addDesc("steel", "bg", "Само стомана", "НЛО")
worldmap_addDesc("steel", "sv", "Inget annat än stål", "UFO")
worldmap_addDesc("steel", "pt_BR", "Nada Mais Do Que aço", "UFO")
worldmap_addDesc("steel", "ru", "Ничего кроме стали", "НЛО")

worldmap_addDesc("corridor", "en", "Guarded Corridor", "UFO")
worldmap_addDesc("corridor", "cs", "Přísně střežená chodba", "Ztroskotané UFO")
worldmap_addDesc("corridor", "fr", "Couloir gardé", "ovni")
worldmap_addDesc("corridor", "de", "Bewachter Korridor", "UFO")
worldmap_addDesc("corridor", "it", "Corridoio sorvegliato", "UFO")
worldmap_addDesc("corridor", "pl", "Strzeżony korytarz", "UFO")
worldmap_addDesc("corridor", "es", "Pasillo Resguardado", "OVNI")
worldmap_addDesc("corridor", "nl", "Bewaakte gang", "Vliegende schotel")
worldmap_addDesc("corridor", "bg", "Охраняван коридор", "НЛО")
worldmap_addDesc("corridor", "sv", "Bevakad korridor", "UFO")
worldmap_addDesc("corridor", "pt_BR", "Corredor Protegido", "UFO")
worldmap_addDesc("corridor", "ru", "Охраняемый коридор", "НЛО")

worldmap_addDesc("experiments", "en", "Biological Experiments", "UFO")
worldmap_addDesc("experiments", "cs", "Biologické experimenty", "Ztroskotané UFO")
worldmap_addDesc("experiments", "fr", "Expérience biologique", "ovni")
worldmap_addDesc("experiments", "de", "Biologische Experimente", "UFO")
worldmap_addDesc("experiments", "it", "Esperimenti biologici", "UFO")
worldmap_addDesc("experiments", "pl", "Doświadczenia biologiczne", "UFO")
worldmap_addDesc("experiments", "es", "Experimentos Biológicos", "OVNI")
worldmap_addDesc("experiments", "nl", "Biologische experimenten", "Vliegende schotel")
worldmap_addDesc("experiments", "bg", "Биологически експерименти", "НЛО")
worldmap_addDesc("experiments", "sv", "Biologiska experiment", "UFO")
worldmap_addDesc("experiments", "pt_BR", "Experiências Biológicas", "UFO")
worldmap_addDesc("experiments", "ru", "Биологические эксперименты", "НЛО")

worldmap_addDesc("propulsion", "en", "The Real Propulsion", "UFO")
worldmap_addDesc("propulsion", "cs", "Skutečný pohon", "Ztroskotané UFO")
worldmap_addDesc("propulsion", "fr", "La vraie propulsion", "ovni")
worldmap_addDesc("propulsion", "de", "Der echte Antrieb", "UFO")
worldmap_addDesc("propulsion", "it", "Il vero propulsore", "UFO")
worldmap_addDesc("propulsion", "pl", "Prawdziwy napęd", "UFO")
worldmap_addDesc("propulsion", "es", "La Propulsión Real", "OVNI")
worldmap_addDesc("propulsion", "nl", "De echte aandrijving", "Vliegende schotel")
worldmap_addDesc("propulsion", "bg", "Истинска тяга", "НЛО")
worldmap_addDesc("propulsion", "sv", "Den riktiga drivkraften", "UFO")
worldmap_addDesc("propulsion", "pt_BR", "A Propulsão Real", "UFO")
worldmap_addDesc("propulsion", "ru", "Сила инстинкта", "НЛО")

worldmap_addDesc("aztec", "en", "Aztec Art Hall", "Treasure Cave")
worldmap_addDesc("aztec", "cs", "Sál aztéckého umění", "Jeskyně pokladů")
worldmap_addDesc("aztec", "fr", "La salle d'art Aztèque", "La grotte au trésor")
worldmap_addDesc("aztec", "de", "Azteken Kunstaustellung", "Schatzhöhle")
worldmap_addDesc("aztec", "it", "Museo d'arte azteca", "La grotta del tesoro")
worldmap_addDesc("aztec", "pl", "Wystawa sztuki azteckiej", "Grota skarbów")
worldmap_addDesc("aztec", "es", "Salón de Arte Azteca", "Caverna del Tesoro")
worldmap_addDesc("aztec", "nl", "Azteekse kunstverzameling", "De grot met de schat")
worldmap_addDesc("aztec", "bg", "Ацтекско изкуство", "Пещерата със съкровищата")
worldmap_addDesc("aztec", "sv", "Aztekernas konsthall", "Skattgrottan")
worldmap_addDesc("aztec", "pt_BR", "Salão de Arte Azteca", "A Caverna do Tesouro")
worldmap_addDesc("aztec", "ru", "Музей искусства ацтеков", "Пещера с сокровищами")

worldmap_addDesc("gems", "en", "Shiny Cave-in", "Treasure Cave")
worldmap_addDesc("gems", "cs", "Blýskavý zával", "Jeskyně pokladů")
worldmap_addDesc("gems", "fr", "La grotte lumineuse", "La grotte au trésor")
worldmap_addDesc("gems", "de", "Glänzender Einsturz", "Schatzhöhle")
worldmap_addDesc("gems", "it", "Immersi nello splendore", "La grotta del tesoro")
worldmap_addDesc("gems", "pl", "Lśniąca jaskinia", "Grota skarbów")
worldmap_addDesc("gems", "es", "Gruta Luminosa", "Caverna del Tesoro")
worldmap_addDesc("gems", "nl", "Schitterend ingestort", "De grot met de schat")
worldmap_addDesc("gems", "bg", "Блестяща пещера", "Пещерата със съкровищата")
worldmap_addDesc("gems", "sv", "Skimrande gruvras", "Skattgrottan")
worldmap_addDesc("gems", "pt_BR", "Caverna Luminosa", "A Caverna do Tesouro")
worldmap_addDesc("gems", "ru", "Сверкающий обвал", "Пещера с сокровищами")

worldmap_addDesc("chest", "en", "Giant’s Chest", "Treasure Cave")
worldmap_addDesc("chest", "cs", "Truhlička obra Koloděje", "Jeskyně pokladů")
worldmap_addDesc("chest", "fr", "Le coffre géant", "La grotte au trésor")
worldmap_addDesc("chest", "de", "Die Truhe des Giganten", "Schatzhöhle")
worldmap_addDesc("chest", "it", "Lo scrigno del gigante", "La grotta del tesoro")
worldmap_addDesc("chest", "pl", "Kufer olbrzyma", "Grota skarbów")
worldmap_addDesc("chest", "es", "El Pecho del Gigante", "Caverna del Tesoro")
worldmap_addDesc("chest", "nl", "De gigantische schatkist", "De grot met de schat")
worldmap_addDesc("chest", "bg", "Сандъка на гиганта", "Пещерата със съкровищата")
worldmap_addDesc("chest", "sv", "Jättens kista", "Skattgrottan")
worldmap_addDesc("chest", "pt_BR", "O Cofre do Gigante", "A Caverna do Tesouro")
worldmap_addDesc("chest", "ru", "Гигантский сундук", "Пещера с сокровищами")

worldmap_addDesc("alibaba", "en", "The Hall of Ali-baba", "Treasure Cave")
worldmap_addDesc("alibaba", "cs", "Alibabův sál", "Jeskyně pokladů")
worldmap_addDesc("alibaba", "fr", "La caverne d'Ali Baba", "La grotte au trésor")
worldmap_addDesc("alibaba", "de", "Die Halle von Ali Baba", "Schatzhöhle")
worldmap_addDesc("alibaba", "it", "La camera di Ali-baba", "La grotta del tesoro")
worldmap_addDesc("alibaba", "pl", "Komnata Ali-Baby", "Grota skarbów")
worldmap_addDesc("alibaba", "es", "El Salón de Ali Baba", "Caverna del Tesoro")
worldmap_addDesc("alibaba", "nl", "De hal van Ali-Baba", "De grot met de schat")
worldmap_addDesc("alibaba", "bg", "Залата на Али Баба", "Пещерата със съкровищата")
worldmap_addDesc("alibaba", "sv", "Alibabas grotta", "Skattgrottan")
worldmap_addDesc("alibaba", "pt_BR", "O Salão de Ali-baba", "A Caverna do Tesouro")
worldmap_addDesc("alibaba", "ru", "Коридор Али-Бабы", "Пещера с сокровищами")

worldmap_addDesc("cave", "en", "The Deepest Cave", "Treasure Cave")
worldmap_addDesc("cave", "cs", "Nejhlubší jeskyně", "Jeskyně pokladů")
worldmap_addDesc("cave", "fr", "La cave la plus profonde", "La grotte au trésor")
worldmap_addDesc("cave", "de", "Die tiefste Höhle", "Schatzhöhle")
worldmap_addDesc("cave", "it", "La più profonda", "La grotta del tesoro")
worldmap_addDesc("cave", "pl", "Najgłębsza jaskinia", "Grota Skarbów")
worldmap_addDesc("cave", "es", "La Caverna mas Profunda", "Caverna del Tesoro")
worldmap_addDesc("cave", "nl", "De diepste grot", "De grot met de schat")
worldmap_addDesc("cave", "bg", "Най-дълбоката пещера", "Пещерата със съкровищата")
worldmap_addDesc("cave", "sv", "Den djupaste grottan", "Skattgrottan")
worldmap_addDesc("cave", "pt_BR", "A Caverna mais Profunda", "A Caverna do Tesouro")
worldmap_addDesc("cave", "ru", "Глубочайшая пещера", "Пещера с сокровищами")

worldmap_addDesc("grail", "en", "What Would King Arthur Say?", "Treasure Cave")
worldmap_addDesc("grail", "cs", "Artuš by se divil", "Jeskyně pokladů")
worldmap_addDesc("grail", "fr", "Qu'aurait dit le roi Arthur ?", "La grotte au trésor")
worldmap_addDesc("grail", "de", "Was würde König Arthur sagen?", "Schatzhöhle")
worldmap_addDesc("grail", "it", "Cosa direbbe Re Artù?", "La grotta del tesoro")
worldmap_addDesc("grail", "pl", "Co by powiedział Król Artur?", "Grota skarbów")
worldmap_addDesc("grail", "es", "¿Qué Diría el Rey Arturo?", "Caverna del Tesoro")
worldmap_addDesc("grail", "nl", "Wat zou Koning Arthur ervan zeggen?", "De grot met de schat")
worldmap_addDesc("grail", "bg", "Какво ли би казал крал Артур?", "Пещерата със съкровищата")
worldmap_addDesc("grail", "sv", "Vad skulle kung Arthur ha sagt?", "Skattgruvan")
worldmap_addDesc("grail", "pt_BR", "O que diria Rei Arthur?", "A Caverna do Tesouro")
worldmap_addDesc("grail", "ru", "Что бы сказал король Артур?", "Пещера с сокровищами")

worldmap_addDesc("tetris", "en", "TETRIS", "Secret Computer")
worldmap_addDesc("tetris", "cs", "TETRIS", "Tajný počítač")
worldmap_addDesc("tetris", "fr", "TETRIS", "l'ordinateur secret")
worldmap_addDesc("tetris", "de", "TETRIS", "Geheimer Rechner")
worldmap_addDesc("tetris", "it", "TETRIS", "Il computer segreto")
worldmap_addDesc("tetris", "pl", "TETRIS", "Tajemniczy komputer")
worldmap_addDesc("tetris", "es", "TETRIS", "Computador Secreto")
worldmap_addDesc("tetris", "nl", "TETRIS", "Geheime computer")
worldmap_addDesc("tetris", "bg", "ТЕТРИС", "Тайният компютър")
worldmap_addDesc("tetris", "sv", "TETRIS", "Hemlig dator")
worldmap_addDesc("tetris", "pt_BR", "TETRIS", "Computador Secreto")
worldmap_addDesc("tetris", "ru", "ТЕТРИС", "Секретный компьютер")

worldmap_addDesc("emulator", "en", "Emulator", "Secret Computer")
worldmap_addDesc("emulator", "cs", "Emulátor", "Tajný počítač")
worldmap_addDesc("emulator", "fr", "Emulateur", "l'ordinateur secret")
worldmap_addDesc("emulator", "de", "Emulator", "Geheimer Rechner")
worldmap_addDesc("emulator", "it", "Emulatore", "Il computer segreto")
worldmap_addDesc("emulator", "pl", "Emulator", "Tajemniczy komputer")
worldmap_addDesc("emulator", "es", "Emulador", "Computador Secreto")
worldmap_addDesc("emulator", "nl", "Emulator", "Geheime computer")
worldmap_addDesc("emulator", "bg", "Емулатор", "Тайният компютър")
worldmap_addDesc("emulator", "sv", "Emulator", "Hemlig dator")
worldmap_addDesc("emulator", "pt_BR", "Emulador", "Computador Secreto")
worldmap_addDesc("emulator", "ru", "Эмулятор", "Секретный компьютер")

worldmap_addDesc("warcraft", "en", "Garden of War", "Secret Computer")
worldmap_addDesc("warcraft", "cs", "Garden of War", "Tajný počítač")
worldmap_addDesc("warcraft", "fr", "Jardin de guerre", "l'ordinateur secret")
worldmap_addDesc("warcraft", "de", "Garten des Krieges", "Geheimer Rechner")
worldmap_addDesc("warcraft", "it", "Campo di battaglia", "Il computer segreto")
worldmap_addDesc("warcraft", "pl", "Wojenny ogród", "Tajemniczy komputer")
worldmap_addDesc("warcraft", "es", "Jardín de Guerra", "Computador Secreto")
worldmap_addDesc("warcraft", "nl", "Oorlogstuin", "Geheime computer")
worldmap_addDesc("warcraft", "bg", "Военна градина", "Тайният компютър")
worldmap_addDesc("warcraft", "sv", "Krigsträdgården", "Hemlig dator")
worldmap_addDesc("warcraft", "pt_BR", "Jardim da Guerra", "Computador Secreto")
worldmap_addDesc("warcraft", "ru", "Сад войны", "Секретный компьютер")

worldmap_addDesc("windoze", "en", "Favorites", "Secret Computer")
worldmap_addDesc("windoze", "cs", "Oblíbené položky", "Tajný počítač")
worldmap_addDesc("windoze", "fr", "Favoris", "l'ordinateur secret")
worldmap_addDesc("windoze", "de", "Lesezeichen", "Geheimer Rechner")
worldmap_addDesc("windoze", "it", "Preferiti", "Il computer segreto")
worldmap_addDesc("windoze", "pl", "Ulubieńcy", "Tajemniczy komputer")
worldmap_addDesc("windoze", "es", "Favoritos", "Computador Secreto")
worldmap_addDesc("windoze", "nl", "Leestekens", "Geheime computer")
worldmap_addDesc("windoze", "bg", "Любими", "Тайният компютър")
worldmap_addDesc("windoze", "sv", "Favoriter", "Hemlig dator")
worldmap_addDesc("windoze", "pt_BR", "Favoritos", "Computador Secreto")
worldmap_addDesc("windoze", "ru", "Избранное", "Секретный компьютер")

worldmap_addDesc("hardware", "en", "A Hardware Problem", "Secret Computer")
worldmap_addDesc("hardware", "cs", "Hardwarový problém", "Tajný počítač")
worldmap_addDesc("hardware", "fr", "Problème matériel", "l'ordinateur secret")
worldmap_addDesc("hardware", "de", "Ein Hardwareproblem", "Geheimer Rechner")
worldmap_addDesc("hardware", "it", "Problemi di hardware", "Il computer segreto")
worldmap_addDesc("hardware", "pl", "Problem sprzętowy", "Tajemniczy komputer")
worldmap_addDesc("hardware", "es", "Un Problema de Hardware", "Computador Secreto")
worldmap_addDesc("hardware", "nl", "Een hardwareprobleem", "Geheime computer")
worldmap_addDesc("hardware", "bg", "Хардуерен проблем", "Тайният компютър")
worldmap_addDesc("hardware", "sv", "Ett hårdvaruproblem", "Hemlig dator")
worldmap_addDesc("hardware", "pt_BR", "Um Problema de Hardware", "Computador Secreto")
worldmap_addDesc("hardware", "ru", "Проблема с аппаратным обеспечением", "Секретный компьютер")

worldmap_addDesc("floppy", "en", "Read Only", "Secret Computer")
worldmap_addDesc("floppy", "cs", "Read only", "Tajný počítač")
worldmap_addDesc("floppy", "fr", "En lecture seul", "l'ordinateur secret")
worldmap_addDesc("floppy", "de", "Nur lesen", "Geheimer Rechner")
worldmap_addDesc("floppy", "it", "Sola lettura", "Il computer segreto")
worldmap_addDesc("floppy", "pl", "Tylko do odczytu", "Tajemniczy komputer")
worldmap_addDesc("floppy", "es", "Sólo Lectura", "Computador Secreto")
worldmap_addDesc("floppy", "nl", "Alleen lezen", "Geheime computer")
worldmap_addDesc("floppy", "bg", "Само за четене", "Тайният компютър")
worldmap_addDesc("floppy", "sv", "Ej skrivbar", "Hemlig dator")
worldmap_addDesc("floppy", "pt_BR", "Somente Leitura", "Computador Secreto")
worldmap_addDesc("floppy", "ru", "Только чтение", "Секретный компьютер")

worldmap_addDesc("ending", "en", "At Home", "Fish House")
worldmap_addDesc("ending", "cs", "Doma", "Rybí domeček")
worldmap_addDesc("ending", "fr", "A la maison", "Maison Poisson")
worldmap_addDesc("ending", "de", "Zu Hause", "Fischhaus")
worldmap_addDesc("ending", "it", "A casa", "La casa dei pesci")
worldmap_addDesc("ending", "pl", "W domu", "Rybi domek")
worldmap_addDesc("ending", "es", "En Casa", "Casa Pez")
worldmap_addDesc("ending", "nl", "Thuis", "Vissenhuis")
worldmap_addDesc("ending", "bg", "У дома", "Дома на рибките")
worldmap_addDesc("ending", "sv", "Hemma", "Fiskhuset")
worldmap_addDesc("ending", "pt_BR", "Em Casa", "Peixaria")
worldmap_addDesc("ending", "ru", "Дома", "Рыбий дом")

worldmap_addDesc("score", "en", "Special Score", "")
worldmap_addDesc("score", "cs", "Special Score", "")
worldmap_addDesc("score", "fr", "Spécial Score", "")
worldmap_addDesc("score", "de", "Spezial-Spielstand", "")
worldmap_addDesc("score", "it", "Puntata speciale", "")
worldmap_addDesc("score", "pl", "Special Score", "")
worldmap_addDesc("score", "es", "Puntaje Especial", "")
worldmap_addDesc("score", "nl", "Speciale score", "")
worldmap_addDesc("score", "bg", "Специален резултат", "")
worldmap_addDesc("score", "sv", "Specialpoäng", "")
worldmap_addDesc("score", "pt_BR", "Pontuação Especial", "")
worldmap_addDesc("score", "ru", "Специальный счёт", "")

worldmap_addDesc("fdto", "en", "FDTO Building", "Branch of New Generation")
worldmap_addDesc("fdto", "cs", "Budova FDTO", "Větev Nové generace")
worldmap_addDesc("fdto", "de", "Haus FDTO", "Zweig der neuen Generation")
worldmap_addDesc("fdto", "pl", "Kwatera FDTO", "NG")
worldmap_addDesc("fdto", "sv", "FDTO högkvarter", "Gren av en ny generation")
worldmap_addDesc("fdto", "nl", "Het VDTO gebouw", "Vissenhuis")
worldmap_addDesc("fdto", "bg", "Сградата на ООРД", "Нова генерация")
worldmap_addDesc("fdto", "sl", "Zgradba RDA", "NG")
worldmap_addDesc("fdto", "pt_BR", "Casa FDTO?", "NG")
worldmap_addDesc("fdto", "ru", "Здание FDTO", "Новая ветвь в NG")

worldmap_addDesc("hole", "en", "Hard Hole", "Branch of New Generation")
worldmap_addDesc("hole", "de", "Tiefer Graben", "Zweig der neuen Generation")
worldmap_addDesc("hole", "cs", "Nepříjemná propast", "Větev Nové generace")
worldmap_addDesc("hole", "sv", "Svårt hål", "Gren av en ny generation")
worldmap_addDesc("hole", "nl", "Een diep gat", "Tak van de nieuwe generatie")
worldmap_addDesc("hole", "bg", "Трудна дупка", "Нова генерация")
worldmap_addDesc("hole", "ru", "Тяжёлая луза", "Новая ветвь в NG")

worldmap_addDesc("key", "en", "Lock and Key", "Branch of New Generation")
worldmap_addDesc("key", "de", "Schlüssel und Schloß", "Zweig der neuen Generation")
worldmap_addDesc("key", "cs", "Zámek a klíč", "Větev Nové generace")
worldmap_addDesc("key", "sv", "Lås och nyckel", "Gren av en ny generation")
worldmap_addDesc("key", "nl", "Slot en grendel", "Tak van de nieuwe generatie")
worldmap_addDesc("key", "bg", "Под ключ", "Нова генерация")
worldmap_addDesc("key", "ru", "Замок и Ключ", "Новая ветвь в NG")

worldmap_addDesc("keys", "en", "Locksmithery", "Branch of New Generation")
worldmap_addDesc("keys", "de", "Schlosserei", "Zweig der neuen Generation")
worldmap_addDesc("keys", "cs", "Zámečnictví", "Větev Nové generace")
worldmap_addDesc("keys", "sv", "Låssmide", "Gren av en ny generation")
worldmap_addDesc("keys", "nl", "Slotenmakerij", "Tak van de nieuwe generatie")
worldmap_addDesc("keys", "bg", "Ключарница", "Нова генерация")
worldmap_addDesc("keys", "ru", "Слесарь", "Новая ветвь в NG")

worldmap_addDesc("hanoi", "en", "Separated", "Branch of New Generation")
worldmap_addDesc("hanoi", "de", "Getrennt", "Zweig der neuen Generation")
worldmap_addDesc("hanoi", "cs", "Odděleni", "Větev Nové Generace")
worldmap_addDesc("hanoi", "sv", "Separerade", "Gren av en ny generation")
worldmap_addDesc("hanoi", "nl", "Uitelkaar", "Tak van de nieuwe generatie")
worldmap_addDesc("hanoi", "bg", "Разделени", "Нова генерация")
worldmap_addDesc("hanoi", "ru", "Отделение", "Новая ветвь в NG")

worldmap_addDesc("rush", "en", "Filled Car Park", "Branch of New Generation")
worldmap_addDesc("rush", "de", "Voller Parkplatz", "Zweig der neuen Generation")
worldmap_addDesc("rush", "cs", "Zaplněné parkoviště", "Větev Nové Generace")
worldmap_addDesc("rush", "sv", "Full parkering", "Gren av en ny generation")
worldmap_addDesc("rush", "nl", "Volle parkeerplek", "Tak van de nieuwe generatie")
worldmap_addDesc("rush", "bg", "Запълнен паркинг", "Нова генерация")
worldmap_addDesc("rush", "ru", "Полная стоянка", "Новая ветвь в NG")

worldmap_addDesc("nowall", "en", "No Wall at All", "Branch of New Generation")
worldmap_addDesc("nowall", "de", "Keine Wände", "Zweig der neuen Generation")
worldmap_addDesc("nowall", "cs", "Vůbec žádná zeď", "Větev Nové Generace")
worldmap_addDesc("nowall", "sv", "Inga väggar alls", "Gren av en ny generation")
worldmap_addDesc("nowall", "nl", "Helemaal geen muren", "Tak van de nieuwe generatie")
worldmap_addDesc("nowall", "bg", "Съвсем без стени", "Нова генерация")
worldmap_addDesc("nowall", "ru", "Нигде нет стен.", "Новая ветвь в NG")

worldmap_addDesc("rotate", "en", "Rotate It", "Branch of New generation")
worldmap_addDesc("rotate", "de", "Dreh es", "Zweig der neuen Generation")
worldmap_addDesc("rotate", "cs", "Roztočte to", "Větev Nové generace")
worldmap_addDesc("rotate", "sv", "Rotera den", "Gren av en ny generation")
worldmap_addDesc("rotate", "nl", "Draai Het", "Gren av en ny generation")
worldmap_addDesc("rotate", "bg", "Завъртете това", "Нова генерация")
worldmap_addDesc("rotate", "ru", "Поверните это", "Новая ветвь в NG")

worldmap_addDesc("linux", "en", "Linuxers Must Be Mad", "Branch of New Generation")
worldmap_addDesc("linux", "de", "Linuxbenutzer müssen verrückt sein", "Zweig der neuen Generation")
worldmap_addDesc("linux", "cs", "Linuxáci musí být šílení", "Větev Nové Generace")
worldmap_addDesc("linux", "ru", "Линуксойд должен быть сумашедшим", "Новая ветвь в NG")
worldmap_addDesc("linux", "sv", "Linuxanvändare måste vara tokiga", "Gren av en ny generation")
worldmap_addDesc("linux", "bg", "Линуксаджиите сигурно са полудели", "Нова генерация")

worldmap_addDesc("electromagnet", "en", "Electromagnet", "UFO Exit")
worldmap_addDesc("electromagnet", "de", "Elektromagnet", "Zweig der neuen Generation")
worldmap_addDesc("electromagnet", "cs", "Elektromagnet", "UFO únik")
worldmap_addDesc("electromagnet", "bg", "Електромагнит", "Изход от НЛО")
worldmap_addDesc("electromagnet", "sv", "Elektromagnet", "UFOutgång")
worldmap_addDesc("electromagnet", "ru", "Электромагнит", "Ветка из НЛО")

